"""Reward function of the environments.
"""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import collections


PushLayout = collections.namedtuple(
    'PushLayout',
    ('size',
     'offset',
     'region',
     'goal',
     'target',
     'obstacle',
     'region_rgba',
     'goal_rgba',
     )
)


TASK_NAME_TO_LAYOUTS = {
    'clearing': [

        PushLayout(
            size=0.15,
            # Offset: [0.6 - 0.76/2 + 0.075, 0 - 1.22/2 + 0.05 + 0.075]
            offset=[0.295, -0.485],
            region=[
                [0, 2], [0, 3], [0, 4], [0, 5],
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
            ],
            goal=None,
            target=[
                [1, 3], [1, 4],
                [2, 3], [2, 4],
            ],
            obstacle=[
                [1, 3], [1, 4],
                [2, 3], [2, 4],
            ],
            region_rgba=[0.4667, 0.7098, 0.9961, 1],
            goal_rgba=None,
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
            ],
            goal=None,
            target=[
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
            ],
            obstacle=[
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
            ],
            region_rgba=[0.4667, 0.7098, 0.9961, 1],
            goal_rgba=None,
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 2], [0, 3], [0, 4], [0, 5],
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 3], [2, 4],
            ],
            goal=None,
            target=[
                [0, 2], [0, 3], [0, 4], [0, 5],
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 3], [2, 4],
            ],
            obstacle=[
                [0, 2], [0, 3], [0, 4], [0, 5],
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 3], [2, 4],
            ],
            region_rgba=[0.4667, 0.7098, 0.9961, 1],
            goal_rgba=None,
        ),

    ],

    'insertion': [

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 0], [0, 1],
                [1, 0], [1, 1],
                [2, 0],
                [3, 0], [3, 1],
                [4, 0], [4, 1],
            ],
            goal=[
                [2, 1],
            ],
            target=[
                [2, 3], [2, 4],
            ],
            obstacle=[
                [1, 3], [1, 4],
                [2, 3], [2, 4],
                [3, 3], [3, 4],
            ],
            region_rgba=[1, .4235, .4235, 1],
            goal_rgba=[0.867, 0.776, 0.678, 0],
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 0], [0, 1],
                [1, 0], [1, 1],
                [2, 0],
                [3, 0], [3, 1],
                [4, 0], [4, 1],
            ],
            goal=[
                [2, 1],
            ],
            target=[
                [2, 3], [2, 4],
            ],
            obstacle=[
                [1, 3], [1, 4],
                [2, 3], [2, 4],
                [3, 3], [3, 4],
            ],
            region_rgba=[1, .4235, .4235, 1],
            goal_rgba=[0.867, 0.776, 0.678, 0],
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [3, 1], [3, 2], [3, 5], [3, 6],
                [4, 1], [4, 2], [4, 3], [4, 4], [4, 5], [4, 6]
            ],
            goal=[
                [2, 1],
            ],
            target=[
                [1, 2], [1, 3], [1, 4], [1, 5],
            ],
            obstacle=[
                [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
            ],
            region_rgba=[1, .4235, .4235, 1],
            goal_rgba=[0.867, 0.776, 0.678, 0],
        ),
    ],

    'crossing': [
        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 0], [0, 2], [0, 5],
                [1, 0], [1, 1], [1, 2], [1, 5],
                [2, 2], [2, 3], [2, 4], [2, 5],
                [3, 2],
            ],
            goal=[
                [1, 2],
            ],
            target=[
                [2, 5],
            ],
            obstacle=[
                [1, 1], [1, 2], [1, 3], [1, 4], [1, 5], [1, 6],
                [2, 1], [2, 2], [2, 3], [2, 4], [2, 5], [2, 6],
                [3, 1], [3, 2], [3, 3], [3, 4], [3, 5], [3, 6],
            ],
            region_rgba=[0.8, 0.8, 0.8, 1],
            goal_rgba=[1, 0.9412, 0.4235, 1],
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 0], [0, 1], [0, 2], [0, 5],
                [1, 0], [1, 2], [1, 3], [1, 4], [1, 5],
                [2, 0], [2, 2], [2, 5],
                [3, 2], [3, 5],
            ],
            goal=[
                [3, 2],
            ],
            target=[
                [1, 4],
                [1, 5],
            ],
            obstacle=[
                [1, 1], [1, 2], [1, 3], [1, 4], [1, 5], [1, 6],
                [2, 1], [2, 2], [2, 3], [2, 4], [2, 5], [2, 6],
                [3, 1], [3, 2], [3, 3], [3, 4], [3, 5], [3, 6],
            ],
            region_rgba=[0.8, 0.8, 0.8, 1],
            goal_rgba=[1, 0.9412, 0.4235, 1],
        ),

        PushLayout(
            size=0.15,
            offset=[0.295, -0.485],
            region=[
                [0, 2], [0, 5],
                [1, 2], [1, 5], [1, 6],
                [2, 1], [2, 2], [2, 3], [2, 4], [2, 5],
                [3, 1], [3, 2], [3, 5],
            ],
            goal=[
                [1, 6],
            ],
            target=[
                [1, 2],
                [2, 1],
                [2, 2],
            ],
            obstacle=[
                [1, 1], [1, 2], [1, 3], [1, 4], [1, 5], [1, 6],
                [2, 1], [2, 2], [2, 3], [2, 4], [2, 5], [2, 6],
                [3, 1], [3, 2], [3, 3], [3, 4], [3, 5], [3, 6],
            ],
            region_rgba=[0.8, 0.8, 0.8, 1],
            goal_rgba=[1, 0.9412, 0.4235, 1],
        ),
    ]
}
